@@ -49,6 +49,10 @@
 #include "pixmaps/Rating_bad.ico.xpm"
 #include "pixmaps/eDonkeyHybrid.ico.xpm"
 
+// lagloose
+#include <wx/font.h>
+// end lagloose
+
 //#define DLC_DT_TEXT (DT_LEFT|DT_SINGLELINE|DT_VCENTER|DT_NOPREFIX|DT_END_ELLIPSIS)
 
 #define DLC_BARUPDATE 512
@@ -69,6 +73,10 @@ BEGIN_EVENT_TABLE(CDownloadListCtrl,CMuleListCtrl)
   EVT_LIST_COL_CLICK(ID_DLOADLIST,CDownloadListCtrl::OnColumnClick)
   EVT_LIST_ITEM_ACTIVATED(ID_DLOADLIST,CDownloadListCtrl::OnLvnItemActivate)
   EVT_LIST_ITEM_RIGHT_CLICK(ID_DLOADLIST,CDownloadListCtrl::OnNMRclick)
+  // lagloose
+  EVT_KEY_UP(CDownloadListCtrl::OnKeyUp)
+  EVT_KEY_DOWN(CDownloadListCtrl::OnKeyDown)
+  // end lagloose
 END_EVENT_TABLE()
 
 // not like this
@@ -1392,6 +1400,15 @@ void CDownloadListCtrl::OnLvnItemActivate(wxListEvent& evt){
 	  wxString status;
 	  int imageID=-1;
 	  
+	// lagloose
+	if(isShift) {
+		uint8 ds = client->GetDownloadState();
+		if( ds != DS_DOWNLOADING) {
+			continue;
+		}
+	}
+	// end lagloose
+
 	  int newid=InsertItem(evt.GetIndex()+1,textData);
 	  wxListItem newitem;
 	  newitem.m_itemId=newid;
@@ -1407,6 +1424,10 @@ void CDownloadListCtrl::OnLvnItemActivate(wxListEvent& evt){
       HideSources(partfile,false,false,false);
     }
   }
+
+  // lagloose
+  isShift = false;
+  // end lagloose
   //*pResult = 0;
 }
 
@@ -2084,3 +2105,20 @@ bool CDownloadListCtrl::ShowItemInCurrentCat(CPartFile* file,int newsel) {
 		(newsel==0 && theApp.glob_prefs->ShowAllNotCats() && file->GetCategory()==0 )) ||
 		( newsel>0 && newsel==file->GetCategory() ) );
 }
+
+//lagloose
+void CDownloadListCtrl::OnKeyUp(wxKeyEvent& event) {
+	isShift = false;
+	event.Skip();
+}
+
+void CDownloadListCtrl::OnKeyDown(wxKeyEvent& event) {
+	if (event.KeyCode() == WXK_SHIFT) {
+		isShift = true;
+	} else {
+		isShift = false;
+	}
+	event.Skip();
+}
+// end lagloose
+
