@@ -829,6 +829,9 @@ void CSearchDlg::DeleteSearch(uint16 nSearchID){
 #ifdef DEBUG
 	printf("debug: want to delete search with id = %d\n", nSearchID);
 #endif
+
+	wxMutexLocker sLock(nb->m_LockTabs);
+
 	if(nb->GetPageCount() > 0) {
 	    /*
 	      Remove the notebook page
@@ -861,7 +864,11 @@ void CSearchDlg::DeleteSearch(uint16 nSearchID){
 		  if (i++ == nb->GetPageCount()) { 
 		  	OnBnClickedCancels(nullEvent);
 		  }
-		  
+		  /*
+		    Force further actions on the searchlistctrl to fail
+		  */
+		  ((CSearchListCtrl *)slctrl)->InvalidateSearchId();
+
 		  /*
 		    ToDo: remove searchlistctrl (slctrl) ?
 		  */
@@ -869,6 +876,7 @@ void CSearchDlg::DeleteSearch(uint16 nSearchID){
 		}
 	    }
 	}
+
 #if 0
 	TCITEM item;
 	item.mask = TCIF_PARAM;
