@@ -106,7 +106,8 @@ void CStatisticsDlg::Init()
 
   // setup tree
   wxTreeItemId root=stattree->AddRoot(_("Statistics"));
-  h_transfer= stattree->InsertItem(root,0L,GetResString(IDS_FSTAT_TRANSFER));
+  h_uptime = stattree->InsertItem(root,0L,GetResString(IDS_FSTAT_WAITING));
+  h_transfer= stattree->AppendItem(root,GetResString(IDS_FSTAT_TRANSFER));
   tran0= stattree->AppendItem(h_transfer,GetResString(IDS_FSTAT_WAITING));
 
   h_upload = stattree->AppendItem(h_transfer,GetResString(IDS_TW_UPLOADS));
@@ -184,6 +185,7 @@ void CStatisticsDlg::Init()
   shar3= stattree->AppendItem(h_shared,GetResString(IDS_FSTAT_WAITING));
   
   stattree->Expand(root);
+  stattree->Expand(h_uptime);
   stattree->Expand(h_transfer);//,TVE_EXPAND);
   stattree->Expand(h_connection);//,TVE_EXPAND);
   stattree->Expand(h_clients);//,TVE_EXPAND);
@@ -286,7 +288,7 @@ void CStatisticsDlg::SetCurrentRate(float uploadrate, float downloadrate) {
         UpDown* updown=new UpDown();
         updown->upload = uploadrate;
         updown->download = downloadrate;
-        theApp.webserver->AddStatsLine(updown);
+//        theApp.webserver->AddStatsLine(updown);
 
 	// averages
 	m_dPlotDataDown[0]=	GetAvgDownloadRate(AVG_SESSION);
@@ -366,6 +368,8 @@ void CStatisticsDlg::ShowStatistics() {
 
 	uint64 DownOHTotal = theApp.downloadqueue->GetDownDataOverheadFileRequest() + theApp.downloadqueue->GetDownDataOverheadSourceExchange() + theApp.downloadqueue->GetDownDataOverheadServer() + theApp.downloadqueue->GetDownDataOverheadOther();
 	uint64 DownOHTotalPackets = theApp.downloadqueue->GetDownDataOverheadFileRequestPackets() + theApp.downloadqueue->GetDownDataOverheadSourceExchangePackets() + theApp.downloadqueue->GetDownDataOverheadServerPackets() + theApp.downloadqueue->GetDownDataOverheadOtherPackets();
+	cbuffer.Format("Uptime: ");
+	stattree->SetItemText(h_uptime, cbuffer);
 	cbuffer.Format(GetResString(IDS_STATS_DDATA),CastItoXBytes( theApp.stat_sessionReceivedBytes).GetData(),	CastItoXBytes( theApp.stat_sessionReceivedBytes+theApp.glob_prefs->GetTotalDownloaded()).GetData());
 	stattree->SetItemText(down1, cbuffer);
 	cbuffer.Format(GetResString(IDS_TOVERHEAD),	CastItoXBytes(DownOHTotal).GetData(), CastItoIShort(DownOHTotalPackets).GetData());
@@ -428,6 +432,12 @@ void CStatisticsDlg::ShowStatistics() {
 	}
 	stattree->SetItemText(con4, cbuffer);
 
+	if (theApp.Start_time>0) {
+		running=(GetTickCount()-theApp.Start_time)/1000;
+		cbuffer.Format("Uptime: %s",CastSecondsToHM(running).GetData());
+		stattree->SetItemText(h_uptime, cbuffer);
+	}
+
 	if (theApp.stat_serverConnectTime==0) cbuffer.Format(GetResString(IDS_STATS_WAITCONN)); else {
 		running=(GetTickCount()-theApp.stat_serverConnectTime)/1000;
 		cbuffer.Format(GetResString(IDS_STATS_CONNECTEDSINCE),CastSecondsToHM(running).GetData());
