@@ -536,8 +536,21 @@ void CUploadListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRe
 	    Sbuffer = "?";
 	  break;
 	case 2:
-	  Sbuffer.Format("%.1f %s",(float)client->GetDatarate()/1024,GetResString(IDS_KBYTESEC).GetData());
-	  break;
+		// lagloose -- Enhanced upload stats
+		if (client->GetDownloadState() == DS_DOWNLOADING) {
+			CString rbuffer;
+			Sbuffer = "";
+			rbuffer.Format("%.1f",(float)client->GetDatarate()/1024);
+			Sbuffer.Append(rbuffer);
+			Sbuffer.Append("/");
+			rbuffer.Format("%.1f %s",(float) client->GetDownloadDatarate()/1024, GetResString(IDS_KBYTESEC).GetData());
+			Sbuffer.Append(rbuffer);
+		} else {
+			Sbuffer.Format("%.1f %s",(float)client->GetDatarate()/1024,GetResString(IDS_KBYTESEC).GetData());
+		}
+		// end lagloose
+
+	  	break;
 	case 3:
 	  
 	  Sbuffer.Format("%s",CastItoXBytes(client->GetSessionUp()).GetData());	
@@ -557,7 +570,14 @@ void CUploadListCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRe
 	    Sbuffer = GetResString(IDS_CONNVIASERVER);
 	    break;
 	  case US_UPLOADING:
-	    Sbuffer = GetResString(IDS_TRANSFERRING);
+	    // lagloose -- Enhanced upload stats
+	    Sbuffer = "<-- ";
+	    Sbuffer.Append(GetResString(IDS_TRANSFERRING));
+	    if (client->GetDownloadState() == DS_DOWNLOADING) {
+		Sbuffer.Append(" -->");
+	    }
+	    // Sbuffer = GetResString(IDS_TRANSFERRING);
+	    // end lagloose
 	    break;
 	  default:
 	    Sbuffer = GetResString(IDS_UNKNOWN);
