@@ -33,7 +33,6 @@
 #include <wx/splash.h>
 #include "muuli_wdr.h"
 //#include "splash_wdr.h"
-#include "pixmaps/About.jpg.xpm"
 
 #include <wx/filesys.h>
 #include <wx/fs_zip.h>
@@ -55,8 +54,9 @@ static wxBitmap *splashBmp=NULL;
 //	ON_COMMAND(ID_HELP, CWinApp::OnHelp)
 //END_MESSAGE_MAP()
 
+void InitSplashXRC();
+
 CxmuleApp::CxmuleApp() {
-  splashBmp=new wxBitmap((const char**)About_jpg);
 }
 
 CxmuleApp::~CxmuleApp(){ }
@@ -295,9 +295,13 @@ bool CxmuleApp::OnInit()
 
 	// splashscreen
 	if (theApp.glob_prefs->UseSplashScreen() && !theApp.glob_prefs->GetStartMinimized()){
-		wxSplashScreen* splsh=new wxSplashScreen(*splashBmp,wxSPLASH_CENTRE_ON_SCREEN|wxSPLASH_TIMEOUT,
+		InitSplashXRC();
+		wxImage::AddHandler(new wxJPEGHandler);
+		
+		wxSplashScreen* splsh=new wxSplashScreen(wxXmlResource::Get()->LoadBitmap("About"),wxSPLASH_CENTRE_ON_SCREEN|wxSPLASH_TIMEOUT,
 							 5000,NULL,-1,wxDefaultPosition,wxDefaultSize,
 							 wxSIMPLE_BORDER|wxSTAY_ON_TOP);
+		splsh->Destroy();
 	}
 
 	wxIPV4address myaddr;
@@ -334,7 +338,7 @@ bool CxmuleApp::OnInit()
 	downloadqueue = new CDownloadQueue(glob_prefs,sharedfiles);	// bugfix - do this before creating the uploadqueue
 	uploadqueue = new CUploadQueue(glob_prefs);
 	ipfilter = new CIPFilter();
-	webserver=new CWebServer();	
+//	webserver=new CWebServer();	
 	//INT_PTR nResponse = dlg.DoModal();
 	
 	// init statistics stuff, better do it asap
@@ -371,6 +375,7 @@ bool CxmuleApp::OnInit()
 	theApp.stat_reconnects=0;
 	theApp.stat_transferStarttime=0;
 	theApp.stat_serverConnectTime=0;
+	theApp.Start_time=GetTickCount();
 
 	// Initialize and sort all lists.
 	theApp.xmuledlg->transferwnd->downloadlistctrl->LoadSettings(CPreferences::tableDownload);
@@ -409,8 +414,8 @@ bool CxmuleApp::OnInit()
 	theApp.sharedfiles->Reload(true, true);
 
 	if (glob_prefs->GetWSIsEnabled()) {
-		webserver->ReloadTemplates();
-		webserver->StartServer();
+//		webserver->ReloadTemplates();
+//		webserver->StartServer();
 	}
 	
 	// pretty much ready now. start autoconnect if 
@@ -602,49 +607,106 @@ bool CxmuleApp::CopyTextToClipboard( wxString strText )
     wxTheClipboard->Close();
   }
 }
-
-void CxmuleApp::OnlineSig() // Added By Bouc7 
-{ 
+/* Original implementation by Bouc7 of the eMule Project.
+   xMule Signature idea was designed by BigBob and implemented
+   by Un-Thesis, with design inputs and suggestions from bothie.
+*/
+void CxmuleApp::OnlineSig() // Added By Bouc7
+{
   if (!theApp.glob_prefs->IsOnlineSignatureEnabled()) return;
 
-    char* fullpath = new char[strlen(glob_prefs->GetAppDir())+14]; 
-    sprintf(fullpath,"%sonlinesig.dat",glob_prefs->GetAppDir()); 
-    CFile file; 
-    if (!file.Open(fullpath,CFile::write)) {
-		theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERROR_SAVEFILE)+wxString(" OnlineSig.dat"));
-    } 
-    char buffer[20]; 
-    if (serverconnect->IsConnected()) 
-    { 
-      file.Write("1",1); 
-      file.Write("|",1); 
-      file.Write(serverconnect->GetCurrentServer()->GetListName(),strlen(serverconnect->GetCurrentServer()->GetListName())); 
-      // Not : file.Write(serverconnect->GetCurrentServer()->GetListName(),strlen(serverconnect->GetCurrentServer()- >GetRealName())); 
+    char* emulesig_path = new char[strlen(glob_prefs->GetAppDir())+14];
+	char* xmulesig_path = new char[strlen(glob_prefs->GetAppDir())+13];
 
-      file.Write("|",1); 
-      file.Write(serverconnect->GetCurrentServer()->GetFullIP(),strlen(serverconnect->GetCurrentServer()->GetFullIP())); 
-      file.Write("|",1); 
-      sprintf(buffer,"%d",serverconnect->GetCurrentServer()->GetPort());
-      file.Write(buffer,strlen(buffer)); 
-    } 
-    else 
-      file.Write("0",1); 
+	sprintf(emulesig_path,"%sonlinesig.dat",glob_prefs->GetAppDir());
+	sprintf(xmulesig_path,"%sxmulesig.dat",glob_prefs->GetAppDir());
 
-    file.Write("\n",1); 
-    sprintf(buffer,"%.1f",(float)downloadqueue->GetDatarate()/1024); 
-    file.Write(buffer,strlen(buffer)); 
-    file.Write("|",1); 
-    sprintf(buffer,"%.1f",(float)uploadqueue->GetDatarate()/1024); 
-    file.Write(buffer,strlen(buffer)); 
-    file.Write("|",1); 
-    sprintf(buffer,"%d",uploadqueue->GetWaitingUserCount());
-    //itoa(uploadqueue->GetWaitingUserCount(),buffer,10); 
-    file.Write(buffer,strlen(buffer)); 
+	CFile xmulesig_out, emulesig_out;
+    if (!emulesig_out.Open(emulesig_path, CFile::write)) {
+		theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERROR_SAVEFILE)+wxString(" OnlineSig File"));
+    }
+	if (!xmulesig_out.Open(xmulesig_path, CFile::write)) {
+		theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERROR_SAVEFILE)+wxString(" xMule OnlineSig File"));
+	}
 
-    file.Close(); 
-    delete[] fullpath; 
-    
-} //End Added By Bouc7
+	char buffer[20];
+/* This will be true when called during shutdown - Clean up the sign file. */
+/*	if (zero) {
+		emulesig_out.Write("0\n0.0|0.0|0\n", 12);
+		xmulesig_out.Write("0\n0\n0\n0\n0\n0\n0\n", 14);
+
+		emulesig_out.Close();
+		xmulesig_out.Close();
+
+		delete[] emulesig_path;
+		delete[] xmulesig_path;
+
+		return;
+	}*/
+	
+	if (serverconnect->IsConnected()) {
+		emulesig_out.Write("1",1);
+		emulesig_out.Write("|",1);
+		emulesig_out.Write(serverconnect->GetCurrentServer()->GetListName(),strlen(serverconnect->GetCurrentServer()->GetListName()));
+		// Not : emulesig_out.Write(serverconnect->GetCurrentServer()->GetListName(),strlen(serverconnect->GetCurrentServer()- >GetRealName()));
+
+		emulesig_out.Write("|",1);
+		emulesig_out.Write(serverconnect->GetCurrentServer()->GetFullIP(),strlen(serverconnect->GetCurrentServer()->GetFullIP()));
+		emulesig_out.Write("|",1);
+		sprintf(buffer,"%d",serverconnect->GetCurrentServer()->GetPort());
+		emulesig_out.Write(buffer,strlen(buffer));
+
+
+		xmulesig_out.Write("1",1);
+		xmulesig_out.Write("\n",1);
+		xmulesig_out.Write(serverconnect->GetCurrentServer()->GetListName(),strlen(serverconnect->GetCurrentServer()->GetListName()));
+		// Not : xmulesig_out.Write(serverconnect->GetCurrentServer()->GetListName(),strlen(serverconnect->GetCurrentServer()- >GetRealName()));
+
+		xmulesig_out.Write("\n",1);
+		xmulesig_out.Write(serverconnect->GetCurrentServer()->GetFullIP(),strlen(serverconnect->GetCurrentServer()->GetFullIP()));
+		xmulesig_out.Write("\n",1);
+		xmulesig_out.Write(buffer,strlen(buffer));
+		xmulesig_out.Write("\n",1);
+
+		if (theApp.serverconnect->IsLowID()) {
+			xmulesig_out.Write("L\n",2);
+		} else {
+			xmulesig_out.Write("H\n",2);
+		}
+	}
+	else {
+		emulesig_out.Write("0",1);
+		xmulesig_out.Write("0\n0\n0\n0\n0\n",10);
+	}
+
+	emulesig_out.Write("\n",1);
+	sprintf(buffer,"%.1f",(float)downloadqueue->GetDatarate()/1024);
+	
+	emulesig_out.Write(buffer,strlen(buffer));
+	emulesig_out.Write("|",1);
+	xmulesig_out.Write(buffer,strlen(buffer));
+	xmulesig_out.Write("\n",1);
+
+	sprintf(buffer,"%.1f",(float)uploadqueue->GetDatarate()/1024);
+	emulesig_out.Write(buffer,strlen(buffer));
+	emulesig_out.Write("|",1);
+	xmulesig_out.Write(buffer,strlen(buffer));
+	xmulesig_out.Write("\n",1);
+
+	sprintf(buffer,"%d",uploadqueue->GetWaitingUserCount());
+	//itoa(uploadqueue->GetWaitingUserCount(),buffer,10);
+	emulesig_out.Write(buffer,strlen(buffer));
+	xmulesig_out.Write(buffer,strlen(buffer));
+	xmulesig_out.Write("\n",1);
+
+	sprintf(buffer,"%d", theApp.sharedfiles->GetCount());
+	xmulesig_out.Write(buffer, strlen(buffer));
+
+	emulesig_out.Close();
+	xmulesig_out.Close();
+	delete[] emulesig_path;
+	delete[] xmulesig_path;
+}
 
 #if defined(__Linux__)
 #include <execinfo.h>
