@@ -308,6 +308,43 @@ CxmuleDlg::CxmuleDlg(wxWindow* pParent, wxString title)
 	sourceTrayIconGrey= (HICON)LoadImage(AfxGetInstanceHandle() ,MAKEINTRESOURCE(IDR_TRAYICON_GREY),IMAGE_ICON,16,16,LR_DEFAULTCOLOR);
 	usericon = (HICON)::LoadImage(AfxGetInstanceHandle(),MAKEINTRESOURCE(IDI_USER),IMAGE_ICON,16,16,0);
 #endif
+
+/* Razor 1a - Modif by MikaelB
+   Set client size and position */
+
+  // Create a config base for saving razor preferences
+  wxConfigBase *config = wxConfigBase::Get();
+  // If config haven't been created
+  if (config == NULL) {
+    // exit without saving
+    return;
+  }
+
+  // The section where to save in in file
+  CString section = "/Razor_Preferences/";
+
+  // Main window location and size
+  int x1,y1,x2,y2;
+
+
+  // Saving window size and position
+  x1 = config->Read(_T(section+"MAIN_X_POS"), 0l);
+  y1 = config->Read(_T(section+"MAIN_Y_POS"), 0l);
+  x2 = config->Read(_T(section+"MAIN_X_SIZE"), 0l);
+  y2 = config->Read(_T(section+"MAIN_Y_SIZE"), 0l);
+
+  // If x1 and y1 != 0
+  if((x1 != 0) && (y1 != 0)) {
+    // Redefine location
+    Move(x1,y1);
+  }
+   
+  // If x2 and y2 != 0
+  if((x2 != 0) && (y2 != 0)) {
+    // Redefine size
+    SetClientSize(x2,y2);
+  }
+/* End modif */
 }
 
 class QueryDlg : public wxDialog {
@@ -591,6 +628,33 @@ CxmuleDlg::~CxmuleDlg()
 	::DestroyIcon(sourceTrayIconGrey);
 	::DestroyIcon(usericon);
 #endif
+/* Razor 1a - Modif by MikaelB
+   Save client size and position */
+
+  // Create a config base for saving razor preferences
+  wxConfigBase *config = wxConfigBase::Get();
+  // If config haven't been created
+  if (config == NULL)
+    // exit without saving
+    return;
+
+  // The section where to save in in file
+  CString section = "/Razor_Preferences/";
+
+  // Main window location and size
+  int x1,y1,x2,y2;
+  GetPosition(&x1, &y1);
+  GetSize(&x2,&y2);
+  
+  // Saving window size and position
+  config->Write(_T(section+"MAIN_X_POS"), (long) x1);
+  config->Write(_T(section+"MAIN_Y_POS"), (long) y1);
+  config->Write(_T(section+"MAIN_X_SIZE"), (long) x2);
+  config->Write(_T(section+"MAIN_Y_SIZE"), (long) y2);
+
+  config->Flush(true);
+
+/* End modif */    
 
 }
 #if 0
